@@ -20,9 +20,6 @@ def egcd(a, b):
 
 def modinv(b, n):
     g, x, _ = egcd(b, n)
-    print(x)
-    print(n)
-    print(x%n)
     if g != 1:
         raise Exception('gcd(b, n) != 1')
     return x % n
